diff -Naur uboot.old/drivers/i2c/Makefile uboot/drivers/i2c/Makefile
--- uboot.old/drivers/i2c/Makefile	1969-12-31 19:00:00.000000000 -0500
+++ uboot/drivers/i2c/Makefile	2008-10-16 10:46:50.000000000 -0400
@@ -0,0 +1,47 @@
+#
+# (C) Copyright 2003
+# Wolfgang Denk, DENX Software Engineering, wd@denx.de.
+#
+# See file CREDITS for list of people who contributed to this
+# project.
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; either version 2 of
+# the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+# MA 02111-1307 USA
+#
+#
+include $(TOPDIR)/config.mk
+
+LIB := libi2c.a
+
+OBJS := vsc452_i2c.o
+
+EXTRA_CFLAGS += -I. 
+
+CFLAGS += $(EXTRA_CFLAGS)
+
+
+all:	$(LIB)
+
+$(LIB):	$(OBJS)
+	$(AR) crv $@ $(OBJS)
+
+#########################################################################
+
+.depend:	Makefile $(OBJS:.o=.c)
+		$(CC) -M $(CFLAGS) $(OBJS:.o=.c) > $@
+
+sinclude .depend
+
+#########################################################################
diff -Naur uboot.old/drivers/i2c/vsc452_i2c.c uboot/drivers/i2c/vsc452_i2c.c
--- uboot.old/drivers/i2c/vsc452_i2c.c	1969-12-31 19:00:00.000000000 -0500
+++ uboot/drivers/i2c/vsc452_i2c.c	2008-10-16 10:59:31.000000000 -0400
@@ -0,0 +1,347 @@
+/*
+ * $Id$
+ *
+ * Copyright 2008, Network Appliance Inc.
+ * Author: Jason McMullan <mcmullan@netapp.com>
+ *
+ */
+
+#include <common.h>
+#include <i2c.h>
+#include <asm/io.h>
+
+#include "vsc452/vsc452_i2c.h"
+
+#define I2C_TIMEOUT	200	/* 200ms */
+
+#define WAIT_UNTIL(condition, timeout_ms) \
+	do { \
+		int time_left = timeout_ms * 1000; \
+		while (time_left > 0 && !(condition)) { \
+			udelay((time_left > 100) ? 100 : time_left); \
+			time_left -= (time_left > 100)  ? 100 : time_left; \
+		}; \
+	} while (0); if (!(condition))
+
+int i2c_bus;
+
+static struct vsc452_i2c_bus {
+	int speed;	/* offset into the speed map */
+	uint32_t base;	/* Physical address */
+} i2c[VSC452_I2C_INTERFACES];
+
+static const struct {
+	unsigned int speed;
+	unsigned int select;
+} i2c_speed_map[] = {
+	{ .speed =   78000, .select = SID_CMS_CLK_78KHZ },
+	{ .speed =   98000, .select = SID_CMS_CLK_98KHZ },
+	{ .speed =  284000, .select = SID_CMS_CLK_284KHZ },
+	{ .speed =  340000, .select = SID_CMS_CLK_340KHZ },
+	{ .speed =  347000, .select = SID_CMS_CLK_347KHZ },
+	{ .speed =  417000, .select = SID_CMS_CLK_417KHZ },
+	{ .speed =  852000, .select = SID_CMS_CLK_852KHZ },
+	{ .speed = 1042000, .select = SID_CMS_CLK_1042KHZ },
+};
+
+static inline uint32_t read32(uint32_t base)
+{
+	return *(volatile uint32_t *)(KSEG1ADDR(base));
+}
+
+static inline void write32(uint32_t base, uint32_t val)
+{
+	*(volatile uint32_t *)(KSEG1ADDR(base)) = val;
+}
+
+static inline uint32_t iread(int reg)
+{
+	return read32(i2c[i2c_bus].base + reg);
+}
+
+static inline void iwrite(int reg, uint32_t val)
+{
+	write32(i2c[i2c_bus].base + reg, val);
+}
+int i2c_set_bus_speed (unsigned int speed)
+{
+        int i;
+
+        for (i = 0; i < ARRAY_SIZE(i2c_speed_map); i++) {
+                if (speed <= i2c_speed_map[i].speed) {
+                        break;
+                }
+        }
+
+        /* Too fast? Then select the fastest possible.
+	 */
+        if (i == ARRAY_SIZE(i2c_speed_map)) {
+                i--;
+        }
+
+        i2c[i2c_bus].speed = i;
+        /* Set the speed, do not snoop the bus */
+        iwrite(SIC, SIC_PIN | SIC_ES_CMS);
+        iwrite(SID, i2c_speed_map[i2c[i2c_bus].speed].select);
+
+        /* Return to data i/o mode */
+        iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_ACK);
+
+        return 0;
+}
+
+int i2c_set_bus_num (unsigned int bus)
+{
+	int i;
+
+	if (bus >= VSC452_I2C_INTERFACES) {
+		return -1;
+	}
+
+	i2c_bus = bus;
+	i2c[i2c_bus].base = I2C_BASE(i2c_bus);
+
+	/* Reset the controller */
+	iwrite(SIBC, SIBC_SISR);
+	iwrite(SIBC, SIBC_SCC | SIBC_SDC);
+
+	/* Wiggle out any data on the line */
+	if ((iread(SIBS) & SIBS_SDS) == 0) {
+		for (i = 0; i < 8 * 16; i++) {
+			iwrite(SIBC,        0 | SIBC_SDC);
+			udelay(100);
+			iwrite(SIBC, SIBC_SCC | SIBC_SDC);
+			udelay(100);
+		}
+	}
+
+	/* Master only */
+	iwrite(SIC, SIC_PIN | SIC_ES_SCA);
+	iwrite(SID, SID_SCA_ADDR(0x7F));
+
+	/* Select the bus speed */
+	i2c_set_bus_speed(i2c[i2c_bus].speed);
+
+	return 0;
+}
+
+unsigned int i2c_get_bus_num (void)
+{
+	return i2c_bus;
+}
+
+unsigned int i2c_get_bus_speed (void )
+{
+	return i2c_speed_map[i2c[i2c_bus].speed].speed;
+}
+
+
+#define I2C_STAT(tmp) \
+	do { \
+		debug("Status: 0x%08x (", tmp); \
+		if ((tmp & SIC_PIN) == SIC_PIN) debug("PIN "); \
+		if ((tmp & SIC_SSN) == SIC_SSN) debug("SSN "); \
+		if ((tmp & SIC_STS) == SIC_STS) debug("STS "); \
+		if ((tmp & SIC_BER) == SIC_BER) debug("BER "); \
+		if ((tmp & SIC_LRB) == SIC_LRB) debug("LRB "); \
+		if ((tmp & SIC_AAS) == SIC_AAS) debug("AAS "); \
+		if ((tmp & SIC_LAB) == SIC_LAB) debug("LAB "); \
+		if ((tmp & SIC_BBN) == SIC_BBN) debug("BBN "); \
+		debug(")\n"); \
+	} while (0)
+
+#define I2C_ABORT() do { \
+	i2c_set_bus_num(i2c_bus); \
+} while (0)
+
+
+int i2c_probe(uchar chip)
+{
+	uchar c[2];
+
+	return i2c_read(chip, 0, 0, &c[0], 2);
+}
+
+void i2c_init (int speed,int slaveaddr)
+{
+	// 	i2c_set_bus_speed (speed);
+	i2c_set_bus_num (CFG_CONTROLLER_BUS_NO);
+}
+
+int i2c_read(uchar chip, uint addr, int alen, uchar *buffer, int len)
+{
+	uchar tmp;
+	int i;
+	
+	if (len < 1 || alen < 0) {
+		return -1;
+	}
+
+	/* Wait for bus to stop */
+	WAIT_UNTIL((iread(SIC) & SIC_BBN) == SIC_BBN, I2C_TIMEOUT) {
+		debug("I2C bus timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		I2C_ABORT();
+		return -1;
+	}
+
+	/* Send start */
+	iwrite(SID, SID_DATA((chip << 1) | ((alen == 0) ? 1 : 0)));
+	iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STA | SIC_ACK);
+
+	/* Wait for NAK */
+	WAIT_UNTIL(((tmp = iread(SIC)) & SIC_PIN) == 0, I2C_TIMEOUT) {
+		I2C_STAT(tmp);
+		debug("I2C address timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		I2C_ABORT();
+		return -1;
+	}
+
+	if (tmp & SIC_LRB) {
+		debug("I2C slave NACK, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STO | SIC_ACK);
+		return -1;
+	}
+
+	/* Send address */
+	for (i = 0; i < alen; i++) {
+		I2C_STAT(tmp);
+		if ((tmp & SIC_LRB) != 0) {
+			debug("I2C slave missing, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+			I2C_ABORT();
+			return -1;
+		}
+
+		iwrite(SID, SID_DATA(addr >> ((alen - i - 1) * 8)));
+		WAIT_UNTIL(((tmp = iread(SIC)) & SIC_PIN) == 0, I2C_TIMEOUT) {
+			I2C_STAT(tmp);
+			debug("I2C address timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+			I2C_ABORT();
+			return -1;
+		}
+	}
+
+	if (alen > 0) {
+		/* Send chip id */
+		iwrite(SID, SID_DATA((chip << 1) | 1));
+		/* Send repeated start */
+		iwrite(SIC, SIC_ES_DATA | SIC_STA | SIC_ACK);
+	}
+
+
+	for (i = 0; i < len; i++) {
+		buffer[i] = 0x80 + i;
+	}
+	for (i = -1; i < (len - 1); i++) {
+		WAIT_UNTIL((iread(SIC) & SIC_PIN) == 0, I2C_TIMEOUT) {
+			debug("I2C read timeout, bus = %d, chip = 0x%02x, offset %d\n", i2c_bus, chip, i);
+			I2C_ABORT();
+			return -1;
+		}
+
+		if ((iread(SIC) & SIC_LRB) != 0) {
+			/* Error! */
+			iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STO | SIC_ACK);
+			debug("I2C read error, bus = %d, chip = 0x%02x, offset %d\n", i2c_bus, chip, i);
+			tmp = iread(SID);	/* Throw-away data */
+			I2C_ABORT();
+			return -1;
+		}
+
+		tmp = SID_DATA(iread(SID));
+		if (i >= 0) {
+			buffer[i] = tmp;
+		}
+	}
+
+	iwrite(SIC, SIC_ES_DATA);
+	tmp = SID_DATA(iread(SID));
+	if (i >= 0) {
+		buffer[i] = tmp;
+	}
+
+	WAIT_UNTIL((iread(SIC) & SIC_PIN) == 0, I2C_TIMEOUT) {
+		debug("I2C finish error, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		I2C_ABORT();
+		return -1;
+	}
+
+	iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STO | SIC_ACK);
+	tmp = SID_DATA(iread(SID));
+	buffer[i] = tmp;
+
+	iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_ACK);
+	return 0;
+}
+
+int i2c_write(uchar chip, uint addr, int alen, uchar * buffer, int len)
+{
+	int i;
+	uchar tmp;
+
+	/* Wait for bus to stop */
+	WAIT_UNTIL((iread(SIC) & SIC_BBN) == SIC_BBN, I2C_TIMEOUT) {
+		debug("I2C bus timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		I2C_ABORT();
+		return -1;
+	}
+
+	/* Send start */
+	iwrite(SID, SID_DATA((chip << 1) | 0));
+	iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STA | SIC_ACK);
+
+	/* Wait for NAK */
+	WAIT_UNTIL(((tmp = iread(SIC)) & SIC_PIN) == 0, I2C_TIMEOUT) {
+		I2C_STAT(tmp);
+		debug("I2C NAK timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		I2C_ABORT();
+		return -1;
+	}
+
+	if (tmp & SIC_LRB) {
+		debug("I2C slave NACK, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+		iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STO | SIC_ACK);
+		return -1;
+	}
+
+	/* Send address */
+	for (i = 0; i < alen; i++) {
+		iwrite(SID, SID_DATA(addr >> ((alen - i - 1) * 8)));
+
+		WAIT_UNTIL(((tmp = iread(SIC)) & SIC_PIN) == 0, I2C_TIMEOUT) {
+			I2C_STAT(tmp);
+			debug("I2C address timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+			I2C_ABORT();
+			return -1;
+		}
+
+		if ((iread(SIC) & SIC_LRB) != 0) {
+			debug("I2C slave missing, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+			I2C_ABORT();
+			return -1;
+		}
+	}
+
+	/* Send data */
+	for (i = 0; i < len; i++) {
+		iwrite(SID, SID_DATA(buffer[i]));
+
+		WAIT_UNTIL((iread(SIC) & SIC_PIN) == 0, I2C_TIMEOUT) {
+			debug("I2C address timeout, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+			I2C_ABORT();
+			return -1;
+		}
+
+		if ((iread(SIC) & SIC_LRB) != 0) {
+			debug("I2C slave missing, bus = %d, chip = 0x%02x\n", i2c_bus, chip);
+			I2C_ABORT();
+			return -1;
+		}
+	}
+
+	/* Send stop */
+	iwrite(SIC, SIC_PIN | SIC_ES_DATA | SIC_STO | SIC_ACK);
+
+
+	return 0;
+}
+
diff -Naur uboot.old/include/configs/VSC452EVB.h uboot/include/configs/VSC452EVB.h
--- uboot.old/include/configs/VSC452EVB.h	2008-10-16 10:45:21.000000000 -0400
+++ uboot/include/configs/VSC452EVB.h	2008-10-16 11:02:05.000000000 -0400
@@ -76,7 +76,7 @@
  *---------------------------------------------------------------
  */
 #define CONFIG_COMMANDS		\
-	(CFG_CMD_DHCP|CFG_CMD_NET| CFG_CMD_PING|CFG_CMD_MII|	\
+	(CFG_CMD_EEPROM|CFG_CMD_DHCP|CFG_CMD_NET| CFG_CMD_PING|CFG_CMD_MII|	\
 	CFG_CMD_MEMORY|CFG_CMD_CONSOLE|CFG_CMD_FLASH|		\
 	CFG_CMD_AUTOSCRIPT|CFG_CMD_RUN|CFG_CMD_BDI|		\
 	CFG_CMD_ELF|CFG_CMD_IMLS|CFG_CMD_IMI|			\
@@ -164,6 +164,17 @@
 #define NAND_MAX_CHIPS		1
 
 
+/*---------------------------------------------------------------
+ * EEPROM 
+ *----------------------------------------------------------------
+ */
+#define CFG_I2C_EEPROM_ADDR     0x50
+#define CFG_I2C_EEPROM_ADDR_LEN 2
+#define CONFIG_HARD_I2C         1
+#define CFG_I2C_SLAVE           CFG_I2C_EEPROM_ADDR
+#define CFG_I2C_SPEED           100000
+
+
 /*----------------------------------------------------------------
  *             Physical Memory Map of SDRAM and Flash
  *----------------------------------------------------------------
diff -Naur uboot.old/include/vsc452/vsc452_i2c.h uboot/include/vsc452/vsc452_i2c.h
--- uboot.old/include/vsc452/vsc452_i2c.h	1969-12-31 19:00:00.000000000 -0500
+++ uboot/include/vsc452/vsc452_i2c.h	2008-10-16 10:46:50.000000000 -0400
@@ -0,0 +1,84 @@
+/*
+ * $Id$
+ *
+ * Copyright 2008, Network Appliance Inc.
+ * Author: Jason McMullan <mcmullan@netapp.com>
+ *
+ */
+
+#ifndef ASM_MIPS_ARCH_VSC452_I2C_H
+#define ASM_MIPS_ARCH_VSC452_I2C_H
+
+#define ARRAY_SIZE(x) (sizeof(x) /sizeof((x)[0]))
+
+#define VSC452_I2C_INTERFACES	6
+#define VSC452_I2C_FIFO_MAX	80	/* 80 byte FIFO */
+
+#define I2C_BASE(x)	(0x10200500 + (0x80 * (x)))
+
+#define SID		0x00	/* Serial Interface Data */
+#define SID_DATA(x)		((x) & 0xff)	/* Data */
+#define SID_SCA_MASTER		(1 << 7)	/* Master-only interface */
+#define SID_SCA_ADDR(x)		((x) & 0x7f)	/* Slave address of interface */
+#define SID_SSCA_ENABLE		(1 << 7)	/* Enable SSCA */
+#define SID_SSCA_ADDR(x)	((x) & 0x7f)	/* Secondary Slave address of interface */
+#define SID_CMS_NAS		(1 << 7)	/* Don't snoop the bus */
+#define SID_CMS_CLK_98KHZ	(0 << 0)	/* Clock Select */
+#define SID_CMS_CLK_78KHZ	(1 << 0)	/* Clock Select */
+#define SID_CMS_CLK_347KHZ	(2 << 0)	/* Clock Select */
+#define SID_CMS_CLK_284KHZ	(3 << 0)	/* Clock Select */
+#define SID_CMS_CLK_417KHZ	(4 << 0)	/* Clock Select */
+#define SID_CMS_CLK_340KHZ	(5 << 0)	/* Clock Select */
+#define SID_CMS_CLK_1042KHZ	(6 << 0)	/* Clock Select */
+#define SID_CMS_CLK_852KHZ	(7 << 0)	/* Clock Select */
+
+#define SIC		0x04	/* Serial Interface Control */
+	/* Read Mode */
+#define SIC_PIN		(1 << 7)		/* Pending Interrupt Not */
+#define SIC_SSN		(1 << 6)		/* Start Status Not */
+#define SIC_STS		(1 << 5)		/* Stop Status */
+#define SIC_BER		(1 << 4)		/* Bus Error */
+#define SIC_LRB		(1 << 3)		/* Last Received Bit */
+#define SIC_AAS		(1 << 2)		/* Addressed as Slave */
+#define SIC_LAB		(1 << 1)		/* Lost Arbitaration */
+#define SIC_BBN		(1 << 0)		/* Bus Busy Not */
+	/* Write Mode */
+#define SIC_ES_SCA	(0 << 4)		/* SID is Slave Compare Address */
+#define SIC_ES_SSCA	(7 << 4)		/* SID is Secondary Slave Compare Address */
+#define SIC_ES_DTH	(1 << 4)		/* SID is Data Out Temporary Holding Reg */
+#define SIC_ES_CMS	(2 << 4)		/* SID is Clock and Mode selection */
+#define SIC_ES_DATA	(4 << 4)		/* SID is 8-byte data in/out */
+#define SIC_ENI		(1 << 3)		/* Enable Interrupt */
+#define SIC_STA		(1 << 2)		/* Send Start */
+#define SIC_STO		(1 << 1)		/* Send Stop */
+#define SIC_ACK		(1 << 0)		/* Acknowledge */
+
+#define SIBC		0x08	/* Serial Interface Bit Control */
+#define SIBC_SISR	(1 << 7)		/* Soft Reset */
+#define SIBC_SDIE	(1 << 6)		/* Stop Detected Interrupt Enable */
+#define SIBC_SCC	(1 << 1)		/* Serial Clock Control */
+#define SIBC_SDC	(1 << 0)		/* Serial Data Control */
+
+#define SIBS		0x0c	/* Serial Interface Bit Status */
+#define SIBS_SIIS	(1 << 7)		/* Serial Interface Interrupt Status */
+#define SIBS_SDIS	(1 << 6)		/* Stop Detected Interrupt Status */
+#define SIBS_SCS	(1 << 1)		/* Serial Clock Status */
+#define SIBS_SDS	(1 << 0)		/* Serial Data Status */
+
+#define SIFC		0x10	/* Serial Interface RX FIFO Control */
+#define SIFC_SRFE	(1 << 7)		/* Slave RX FIFO Enable */
+#define SIFC_CRFP	(1 << 6)		/* Clear RX FIFO Pointers */
+#define SIFC_STMIE	(1 << 1)		/* Slave TX Mode Interrupt Enable */
+#define SIFC_RFIE	(1 << 0)		/* RX FIFO Interrupt Enable */
+
+#define SIFS		0x14	/* Serial Interface RX FIFO Status */
+#define SIFS_RFF	(1 << 3)		/* RX FIFO Full */
+#define SIFS_RFE	(1 << 2)		/* RX FIFO Empty */
+#define SIFS_STMIS	(1 << 1)		/* Slave Transmit Mode Interrupt Status */
+#define SIFS_RFIS	(1 << 0)		/* Receive FIFO Interrupt Status */
+
+#define SIFD		0x18	/* Serial Interface RX FIFO Data */
+#define SIFD_FD(x)	((x) & 0xff)		/* FIFO Data */
+
+#endif /* ASM_MIPS_ARCH_VSC452_I2C_H */
+
diff -Naur uboot.old/Makefile uboot/Makefile
--- uboot.old/Makefile	2008-10-16 10:45:19.000000000 -0400
+++ uboot/Makefile	2008-10-16 10:46:14.000000000 -0400
@@ -204,6 +204,7 @@
 LIBS += rtc/librtc.a
 LIBS += dtt/libdtt.a
 LIBS += drivers/spiflash/libspiflash.a
+LIBS += drivers/i2c/libi2c.a
 LIBS += drivers/libdrivers.a
 LIBS += drivers/nand/libnand.a
 LIBS += drivers/nand_legacy/libnand_legacy.a
diff -Naur uboot.old/vendors/ami/fmh/cmd_fmh.c uboot/vendors/ami/fmh/cmd_fmh.c
--- uboot.old/vendors/ami/fmh/cmd_fmh.c	2008-10-16 10:45:17.000000000 -0400
+++ uboot/vendors/ami/fmh/cmd_fmh.c	2008-10-16 11:17:55.000000000 -0400
@@ -79,7 +79,49 @@
 {
 	unsigned short PathID = 5;
 	unsigned char *mac;
-	
+#if 0 // keeping this test code for testing purpose
+	unsigned int offset;
+        unsigned int cnt;
+	unsigned char buffer [20];
+
+	offset = 0x0004;
+        cnt    = 0x06;
+
+	memset (buffer, 0, sizeof (buffer));
+	 eeprom_init ();
+
+	offset = 0;
+	cnt = 4;
+	buffer [0] = 0x30;
+	buffer [1] = 0x31;
+	buffer [2] = 0x32;
+	buffer [3] = 0x33;
+
+	if (0 != eeprom_write (CFG_I2C_EEPROM_ADDR, offset, buffer, cnt))
+	{
+		printf ("Error: Failed to write into eeprom\n");
+	}
+	else
+	{
+		printf ("Write to EEPROM was successful\n");
+
+	}
+	memset (buffer, 0, sizeof (buffer));
+         if (0 != eeprom_read (CFG_I2C_EEPROM_ADDR, offset, buffer, cnt))
+         {
+                   printf ("Error: Failed to read eeprom\n");
+         }
+         else
+         {
+			int j;
+                   printf ("eeprom is read successfully\n");
+		for (j = 0; j < cnt; j++)
+			printf ("0x%02x ", buffer [j]);
+		printf ("\n");
+			
+         }
+
+#endif
 	while (PathID >= 5)
 	{
     	mac = getenv("ethaddr");
